import { d as ListPublishedSiteUrlsRequest$1, a as ListPublishedSiteUrlsResponse$1 } from './urls-api-v2-published-site-urls-site.universal-DsMEwAc2.js';

interface Url {
    /** URL type. */
    urlType?: UrlTypeWithLiterals;
    /** Whether this is the site's primary URL. */
    primary?: boolean;
    /**
     * Published site URL.
     * @maxLength 3000
     */
    url?: string;
    /** Language subdomain info hosted by [Wix multilingual](https://support.wix.com/article/wix-multilingual-adding-and-setting-up-wix-multilingual). */
    multilingualInfo?: MultilingualInfo;
}
declare enum UrlType {
    /** Unknown URL type. */
    UNKNOWN = "UNKNOWN",
    /** Only URLs directing to the Premium version of the site. */
    PREMIUM = "PREMIUM",
    /** Only URLs provided by Wix for free. These URLs include `wixsite.com`. */
    FREE = "FREE"
}
/** @enumType */
type UrlTypeWithLiterals = UrlType | 'UNKNOWN' | 'PREMIUM' | 'FREE';
interface MultilingualInfo {
    /**
     * Language tag in [IETF BCP 47](https://en.wikipedia.org/wiki/IETF_language_tag) format. For example, `en-US`.
     * @format LANGUAGE_TAG
     */
    languageCode?: string;
    /** Whether this is the site's default language. */
    defaultLanguage?: boolean;
}
interface ListPublishedSiteUrlsRequest {
    /** Filters for the list. */
    filters?: Filters;
}
interface Filters {
    /**
     * URL type filter.
     * Default: `ALL`
     */
    urlType?: UrlTypeFilterWithLiterals;
    /** Whether to return only the site's primary URL. <br /> Default: `true`. */
    primary?: boolean | null;
    /** Whether to return language subdomains hosted by [Wix Multilingual](https://support.wix.com/article/wix-multilingual-adding-and-setting-up-wix-multilingual). <br /> Default: `true`. */
    multilingual?: boolean | null;
}
declare enum UrlTypeFilter {
    /** All URLs. */
    ALL = "ALL",
    /** Only URLs directing to the Premium version of the site. */
    PREMIUM = "PREMIUM",
    /** Only URLs provided by Wix for free. These URLs include `wixsite.com`. */
    FREE = "FREE"
}
/** @enumType */
type UrlTypeFilterWithLiterals = UrlTypeFilter | 'ALL' | 'PREMIUM' | 'FREE';
interface ListPublishedSiteUrlsResponse {
    /**
     * List of published site URLs. This array will be empty if the site isn't published.
     * @maxSize 1000
     */
    urls?: Url[];
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function listPublishedSiteUrls(): __PublicMethodMetaInfo<'GET', {}, ListPublishedSiteUrlsRequest$1, ListPublishedSiteUrlsRequest, ListPublishedSiteUrlsResponse$1, ListPublishedSiteUrlsResponse>;

export { type __PublicMethodMetaInfo, listPublishedSiteUrls };
