// src/urls-api-v2-published-site-urls-site.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/urls-api-v2-published-site-urls-site.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressUrlsApiV2UrlsApiUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/urls-server",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/urls-server",
        destPath: "/api"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/urls-server",
        destPath: "/api"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/urls-server/v2/published-site-urls",
        destPath: "/v2/published-site-urls"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_urls_site";
function listPublishedSiteUrls(payload) {
  function __listPublishedSiteUrls({ host }) {
    const metadata = {
      entityFqdn: "wix.urls.api.v2.published_site_urls",
      method: "GET",
      methodFqn: "com.wixpress.urls.api.v2.UrlsApi.ListPublishedSiteUrls",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressUrlsApiV2UrlsApiUrl({
        protoPath: "/v2/published-site-urls",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __listPublishedSiteUrls;
}

// src/urls-api-v2-published-site-urls-site.universal.ts
var UrlType = /* @__PURE__ */ ((UrlType2) => {
  UrlType2["UNKNOWN"] = "UNKNOWN";
  UrlType2["PREMIUM"] = "PREMIUM";
  UrlType2["FREE"] = "FREE";
  return UrlType2;
})(UrlType || {});
var UrlTypeFilter = /* @__PURE__ */ ((UrlTypeFilter2) => {
  UrlTypeFilter2["ALL"] = "ALL";
  UrlTypeFilter2["PREMIUM"] = "PREMIUM";
  UrlTypeFilter2["FREE"] = "FREE";
  return UrlTypeFilter2;
})(UrlTypeFilter || {});
async function listPublishedSiteUrls2(options) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    filters: options?.filters
  });
  const reqOpts = listPublishedSiteUrls(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { filters: "$[0].filters" },
        singleArgumentUnchanged: false
      },
      ["options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/urls-api-v2-published-site-urls-site.public.ts
function listPublishedSiteUrls3(httpClient) {
  return (options) => listPublishedSiteUrls2(
    options,
    // @ts-ignore
    { httpClient }
  );
}

// src/urls-api-v2-published-site-urls-site.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
var listPublishedSiteUrls4 = /* @__PURE__ */ createRESTModule(listPublishedSiteUrls3);
export {
  UrlType,
  UrlTypeFilter,
  listPublishedSiteUrls4 as listPublishedSiteUrls
};
//# sourceMappingURL=index.mjs.map