interface PublishedSiteUrls {
    /**
     * List of published site URLs. This array will be empty if the site isn't published.
     * @maxSize 1000
     */
    urls?: Url[];
}
interface Url {
    /** URL type. */
    urlType?: UrlTypeWithLiterals;
    /** Whether this is the site's primary URL. */
    primary?: boolean;
    /**
     * Published site URL.
     * @maxLength 3000
     */
    url?: string;
    /** Language subdomain info hosted by [Wix multilingual](https://support.wix.com/article/wix-multilingual-adding-and-setting-up-wix-multilingual). */
    multilingualInfo?: MultilingualInfo;
}
declare enum UrlType {
    /** Unknown URL type. */
    UNKNOWN = "UNKNOWN",
    /** Only URLs directing to the Premium version of the site. */
    PREMIUM = "PREMIUM",
    /** Only URLs provided by Wix for free. These URLs include `wixsite.com`. */
    FREE = "FREE"
}
/** @enumType */
type UrlTypeWithLiterals = UrlType | 'UNKNOWN' | 'PREMIUM' | 'FREE';
interface MultilingualInfo {
    /**
     * Language tag in [IETF BCP 47](https://en.wikipedia.org/wiki/IETF_language_tag) format. For example, `en-US`.
     * @format LANGUAGE_TAG
     */
    languageCode?: string;
    /** Whether this is the site's default language. */
    defaultLanguage?: boolean;
}
interface ListPublishedSiteUrlsRequest {
    /** Filters for the list. */
    filters?: Filters;
}
interface Filters {
    /**
     * URL type filter.
     * Default: `ALL`
     */
    urlType?: UrlTypeFilterWithLiterals;
    /** Whether to return only the site's primary URL. <br /> Default: `true`. */
    primary?: boolean | null;
    /** Whether to return language subdomains hosted by [Wix Multilingual](https://support.wix.com/article/wix-multilingual-adding-and-setting-up-wix-multilingual). <br /> Default: `true`. */
    multilingual?: boolean | null;
}
declare enum UrlTypeFilter {
    /** All URLs. */
    ALL = "ALL",
    /** Only URLs directing to the Premium version of the site. */
    PREMIUM = "PREMIUM",
    /** Only URLs provided by Wix for free. These URLs include `wixsite.com`. */
    FREE = "FREE"
}
/** @enumType */
type UrlTypeFilterWithLiterals = UrlTypeFilter | 'ALL' | 'PREMIUM' | 'FREE';
interface ListPublishedSiteUrlsResponse {
    /**
     * List of published site URLs. This array will be empty if the site isn't published.
     * @maxSize 1000
     */
    urls?: Url[];
}
interface ListPublishedSiteUrlsOptions {
    /** Filters for the list. */
    filters?: Filters;
}

export { type Filters as F, type ListPublishedSiteUrlsOptions as L, type MultilingualInfo as M, type PublishedSiteUrls as P, UrlType as U, type ListPublishedSiteUrlsResponse as a, UrlTypeFilter as b, type Url as c, type ListPublishedSiteUrlsRequest as d };
